@@ -5,6 +5,7 @@
 #' @param video_id id of the video; required
 #' @return list with the following elements - publishedAt, channelId, title, description, thumbnails, 
 #' channelTitle, categoryId, liveBroadcastContent, localized, defaultAudioLanguage
+#' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
 #' 
 #' @export
 #' @references \url{https://developers.google.com/youtube/v3/}
@@ -13,7 +14,7 @@
 #' get_details(video_id="N708P-A45D0")
 #' }
 
-get_details <- function (video_id=NULL){
+get_details <- function (video_id=NULL, ...){
 	
 	if (is.null(video_id)) stop("Must specify a video ID")
 
@@ -21,9 +22,9 @@ get_details <- function (video_id=NULL){
 
 	querylist <- list(part="snippet", id = video_id)
 
-	req <- GET("https://www.googleapis.com/youtube/v3/videos",  query=querylist, config(token =  getOption("google_token")))
-	stop_for_status(req)
-	res <- content(req)$items[[1]]$snippet
+	req <- tuber_GET("videos",  querylist, ...)
+	
+	res <- req$items[[1]]$snippet
 
 	# Return a list
 	return(invisible(res))
