@@ -1,6 +1,8 @@
 #' List Languages That Youtube Currently Supports
 #' 
 #' @return data.frame with 3 columns: hl (two letter abbreviation), name (of the language), etag
+#' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
+#' 
 #' @export
 #' @references \url{https://developers.google.com/youtube/v3/docs/i18nLanguages/list}
 #' @examples
@@ -8,7 +10,7 @@
 #' list_langs()
 #' }
 
-list_langs <- function () {
+list_langs <- function (...) {
 
 	querylist <- list(part="snippet")
 
